pub struct QueryLoansRequest {
pub status: i32,
pub pagination: Option<PageRequest>,
}Expand description
QueryLoansRequest is request type for the Query/Loans RPC method.
Fields
status: i32pagination: Option<PageRequest>Implementations
Sourceimpl QueryLoansRequest
impl QueryLoansRequest
Sourcepub fn status(&self) -> LoanStatus
pub fn status(&self) -> LoanStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: LoanStatus)
pub fn set_status(&mut self, value: LoanStatus)
Sets status to the provided enum value.